@@ -82,7 +82,7 @@ usage(FILE *stream, const char *progname)
 	fprintf(stream, "\t-z\t\tdon't randomize the nameservers before use\n");
 	fprintf(stream, "\n  [*] = enables/implies DNSSEC\n");
 	fprintf(stream, "  [**] = can be given more than once\n");
-	fprintf(stream, "\n  ldns-team@nlnetlabs.nl | http://www.nlnetlabs.nl/ldns/\n");
+	fprintf(stream, "\n  dns-team@nlnetlabs.nl | http://www.nlnetlabs.nl/ldns/\n");
 }
 
 /**
@@ -203,6 +203,7 @@ main(int argc, char *argv[])
 	qusevc = false;
 	qrandom = true;
 	key_verified = NULL;
+	ldns_edns_option_list* edns_list = NULL;
 
 	ldns_init_random(NULL, 0);
 
@@ -457,6 +458,31 @@ main(int argc, char *argv[])
 			serv = argv[i] + 1;
 			continue;
 		}
+		/* if ^+ then it's an EDNS option */
+		if (argv[i][0] == '+') {
+			if (!strcmp(argv[i]+1, "nsid")) {
+				ldns_edns_option *edns;
+				edns_list = ldns_edns_option_list_new();
+
+				/* create NSID EDNS*/
+				edns = ldns_edns_new_from_data(LDNS_EDNS_NSID, 0, NULL);
+
+				if (edns_list == NULL || edns == NULL) {
+					error("EDNS option could not be allocated");
+					break;
+				}
+
+				if (!(ldns_edns_option_list_push(edns_list, edns))) {
+					error("EDNS option NSID could not be attached");
+					break;
+				}
+				continue;
+			}
+			else {
+				error("Unsupported argument after '+'");
+				break;
+			}
+		}
 		/* if has a dot, it's a name */
 		if (strchr(argv[i], '.')) {
 			name = argv[i];
@@ -796,7 +822,7 @@ main(int argc, char *argv[])
 			}
 			status = ldns_resolver_prepare_query_pkt(&qpkt, res, qname, type, clas, qflags);
 			if(status != LDNS_STATUS_OK) {
-				error("%s", "making query: %s", 
+				error("%s", "making query: %s",
 					ldns_get_errorstr_by_id(status));
 			}
 			dump_hex(qpkt, query_file);
@@ -867,9 +893,22 @@ main(int argc, char *argv[])
 				} else {
 					/* create a packet and set the RD flag on it */
 					pkt = NULL;
-					status = ldns_resolver_query_status(
-							&pkt, res, qname,
-							type, clas, qflags);
+
+					status = ldns_resolver_prepare_query_pkt(&qpkt,
+						res, qname, type, clas, qflags);
+					if(status != LDNS_STATUS_OK) {
+						error("%s", "making query: %s", 
+							ldns_get_errorstr_by_id(status));
+					}
+
+					if (edns_list) {
+						/* attach the structed EDNS options */
+						ldns_pkt_set_edns_option_list(qpkt, edns_list);
+					}
+
+					status = ldns_resolver_send_pkt(&pkt, res, qpkt);
+					ldns_pkt_free(qpkt);
+
 					if (status != LDNS_STATUS_OK) {
 						error("error sending query: %s"
 						     , ldns_get_errorstr_by_id(
@@ -878,7 +917,8 @@ main(int argc, char *argv[])
 				}
 			}
 			
-			if (!pkt)  {
+			/* now handling the response message/packet */
+			if (!pkt) {
 				mesg("No packet received");
 				result = EXIT_FAILURE;
 			} else {
