@@ -69,7 +69,7 @@ struct ldns_struct_resolver
 	/**  Round trip time; 0 -> infinity. Unit: ms? */
 	size_t *_rtt;
 
-	/**  Wether or not to be recursive */
+	/**  Whether or not to be recursive */
 	bool _recursive;
 
 	/**  Print debug information */
@@ -101,7 +101,7 @@ struct ldns_struct_resolver
 	bool _usevc;
 	/**  Whether to ignore the tc bit */
 	bool _igntc;
-	/**  Whether to use ip6, 0->does not matter, 1 is IPv4, 2 is IPv6 */
+	/**  Whether to use ip6: 0->does not matter, 1 is IPv4, 2 is IPv6 */
 	uint8_t _ip6;
 	/**  If true append the default domain */
 	bool _defnames;
@@ -128,6 +128,8 @@ struct ldns_struct_resolver
 	uint16_t _axfr_i;
 	/* EDNS0 available buffer size */
 	uint16_t _edns_udp_size;
+	/* serial for IXFR */
+	uint32_t _serial;
 
 	/* Optional tsig key for signing queries,
 	outgoing messages are signed if and only if both are set
@@ -138,6 +140,9 @@ struct ldns_struct_resolver
 	char *_tsig_keydata;
 	/** TSIG signing algorithm */
 	char *_tsig_algorithm;
+
+	/** Source address to query from */
+	ldns_rdf *_source;
 };
 typedef struct ldns_struct_resolver ldns_resolver;
 
@@ -151,6 +156,13 @@ typedef struct ldns_struct_resolver ldns_resolver;
  */
 uint16_t ldns_resolver_port(const ldns_resolver *r);
 
+/**
+ * Get the source address the resolver should use
+ * \param[in] r the resolver
+ * \return the source rdf
+ */
+ldns_rdf *ldns_resolver_source(const ldns_resolver *r);
+
 /**
  * Is the resolver set to recurse
  * \param[in] r the resolver
@@ -238,7 +250,7 @@ bool ldns_resolver_dnssec_cd(const ldns_resolver *r);
 /**
  * Get the resolver's DNSSEC anchors
  * \param[in] r the resolver
- * \return an rr_list containg trusted DNSSEC anchors
+ * \return an rr_list containing trusted DNSSEC anchors
  */
 ldns_rr_list * ldns_resolver_dnssec_anchors(const ldns_resolver *r);
 /**
@@ -300,21 +312,24 @@ size_t ldns_resolver_nameserver_rtt(const ldns_resolver *r, size_t pos);
 /**
  * Return the tsig keyname as used by the nameserver
  * \param[in] r the resolver
- * \return the name used.
+ * \return the name used. Still owned by the resolver - change using
+ * ldns_resolver_set_tsig_keyname().
  */
-char *ldns_resolver_tsig_keyname(const ldns_resolver *r);
+const char *ldns_resolver_tsig_keyname(const ldns_resolver *r);
 /**
  * Return the tsig algorithm as used by the nameserver
  * \param[in] r the resolver
- * \return the algorithm used.
+ * \return the algorithm used. Still owned by the resolver - change using
+ * ldns_resolver_set_tsig_algorithm().
  */
-char *ldns_resolver_tsig_algorithm(const ldns_resolver *r);
+const char *ldns_resolver_tsig_algorithm(const ldns_resolver *r);
 /**
  * Return the tsig keydata as used by the nameserver
  * \param[in] r the resolver
- * \return the keydata used.
+ * \return the keydata used. Still owned by the resolver - change using
+ * ldns_resolver_set_tsig_keydata().
  */
-char *ldns_resolver_tsig_keydata(const ldns_resolver *r);
+const char *ldns_resolver_tsig_keydata(const ldns_resolver *r);
 /**
  * pop the last nameserver from the resolver.
  * \param[in] r the resolver
@@ -337,6 +352,13 @@ size_t ldns_resolver_searchlist_count(const ldns_resolver *r);
  */
 void ldns_resolver_set_port(ldns_resolver *r, uint16_t p);
 
+/**
+ * Set the source rdf (address) the resolver should use
+ * \param[in] r the resolver
+ * \param[in] s the source address
+ */
+void ldns_resolver_set_source(ldns_resolver *r, ldns_rdf *s);
+
 /**
  * Set the resolver recursion
  * \param[in] r the resolver
@@ -464,9 +486,10 @@ void ldns_resolver_set_retrans(ldns_resolver *r, uint8_t re);
 void ldns_resolver_set_fallback(ldns_resolver *r, bool fallback);
 
 /**
- * Set the resolver retry interval (in seconds)
+ * Set the number of times a resolver should retry a nameserver before the
+ * next one is tried.
  * \param[in] r the resolver
- * \param[in] re the retry interval
+ * \param[in] re the number of retries
  */
 void ldns_resolver_set_retry(ldns_resolver *r, uint8_t re);
 
@@ -501,23 +524,23 @@ void ldns_resolver_set_edns_udp_size(ldns_resolver *r, uint16_t s);
 /**
  * Set the tsig key name
  * \param[in] r the resolver
- * \param[in] tsig_keyname the tsig key name
+ * \param[in] tsig_keyname the tsig key name (copied into resolver)
  */
-void ldns_resolver_set_tsig_keyname(ldns_resolver *r, char *tsig_keyname);
+void ldns_resolver_set_tsig_keyname(ldns_resolver *r, const char *tsig_keyname);
 
 /**
  * Set the tsig algorithm
  * \param[in] r the resolver
- * \param[in] tsig_algorithm the tsig algorithm
+ * \param[in] tsig_algorithm the tsig algorithm (copied into resolver)
  */
-void ldns_resolver_set_tsig_algorithm(ldns_resolver *r, char *tsig_algorithm);
+void ldns_resolver_set_tsig_algorithm(ldns_resolver *r, const char *tsig_algorithm);
 
 /**
  * Set the tsig key data
  * \param[in] r the resolver
- * \param[in] tsig_keydata the key data
+ * \param[in] tsig_keydata the key data (copied into resolver)
  */
-void ldns_resolver_set_tsig_keydata(ldns_resolver *r, char *tsig_keydata);
+void ldns_resolver_set_tsig_keydata(ldns_resolver *r, const char *tsig_keydata);
 
 /**
  * Set round trip time for all nameservers. Note this currently
@@ -550,7 +573,7 @@ void ldns_resolver_set_random(ldns_resolver *r, bool b);
  * \param[in] n the ip address
  * \return ldns_status a status
  */
-ldns_status ldns_resolver_push_nameserver(ldns_resolver *r, ldns_rdf *n);
+ldns_status ldns_resolver_push_nameserver(ldns_resolver *r, const ldns_rdf *n);
 
 /**
  * Push a new nameserver to the resolver. It must be an
@@ -559,7 +582,7 @@ ldns_status ldns_resolver_push_nameserver(ldns_resolver *r, ldns_rdf *n);
  * \param[in] rr the resource record
  * \return ldns_status a status
  */
-ldns_status ldns_resolver_push_nameserver_rr(ldns_resolver *r, ldns_rr *rr);
+ldns_status ldns_resolver_push_nameserver_rr(ldns_resolver *r, const ldns_rr *rr);
 
 /**
  * Push a new nameserver rr_list to the resolver.
@@ -567,7 +590,7 @@ ldns_status ldns_resolver_push_nameserver_rr(ldns_resolver *r, ldns_rr *rr);
  * \param[in] rrlist the rr_list to push
  * \return ldns_status a status
  */
-ldns_status ldns_resolver_push_nameserver_rr_list(ldns_resolver *r, ldns_rr_list *rrlist);
+ldns_status ldns_resolver_push_nameserver_rr_list(ldns_resolver *r, const ldns_rr_list *rrlist);
 
 /**
  * Send the query for using the resolver and take the search list into account
@@ -578,10 +601,27 @@ ldns_status ldns_resolver_push_nameserver_rr_list(ldns_resolver *r, ldns_rr_list
  * \param[in] t query for this type (may be 0, defaults to A)
  * \param[in] c query for this class (may be 0, default to IN)
  * \param[in] flags the query flags
+ *
  * \return ldns_pkt* a packet with the reply from the nameserver
  */
 ldns_pkt* ldns_resolver_search(const ldns_resolver *r, const ldns_rdf *rdf, ldns_rr_type t, ldns_rr_class c, uint16_t flags);
 
+
+/**
+ * Send the query for using the resolver and take the search list into account
+ * The search algorithm is as follows:
+ * If the name is absolute, try it as-is, otherwise apply the search list
+ * \param[out] pkt a packet with the reply from the nameserver
+ * \param[in] *r operate using this resolver
+ * \param[in] *rdf query for this name
+ * \param[in] t query for this type (may be 0, defaults to A)
+ * \param[in] c query for this class (may be 0, default to IN)
+ * \param[in] flags the query flags
+ *
+ * \return ldns_status LDNS_STATUS_OK on success
+ */
+ldns_status ldns_resolver_search_status(ldns_pkt** pkt, ldns_resolver *r, const ldns_rdf *rdf, ldns_rr_type t, ldns_rr_class c, uint16_t flags);
+
 /**
  * Form a query packet from a resolver and name/type/class combo
  * \param[out] **q a pointer to a ldns_pkt pointer (initialized by this function)
@@ -590,6 +630,7 @@ ldns_pkt* ldns_resolver_search(const ldns_resolver *r, const ldns_rdf *rdf, ldns
  * \param[in] t query for this type (may be 0, defaults to A)
  * \param[in] c query for this class (may be 0, default to IN)
  * \param[in] f the query flags
+ *
  * \return ldns_pkt* a packet with the reply from the nameserver
  */
 ldns_status ldns_resolver_prepare_query_pkt(ldns_pkt **q, ldns_resolver *r, const  ldns_rdf *name, ldns_rr_type t, ldns_rr_class c, uint16_t f);
@@ -602,7 +643,8 @@ ldns_status ldns_resolver_prepare_query_pkt(ldns_pkt **q, ldns_resolver *r, cons
  * \param[in] t query for this type (may be 0, defaults to A)
  * \param[in] c query for this class (may be 0, default to IN)
  * \param[in] flags the query flags
- * \return ldns_pkt* a packet with the reply from the nameserver
+ *
+ * \return ldns_status LDNS_STATUS_OK on success
  */
 ldns_status ldns_resolver_send(ldns_pkt **answer, ldns_resolver *r, const ldns_rdf *name, ldns_rr_type t, ldns_rr_class c, uint16_t flags);
 
@@ -616,11 +658,29 @@ ldns_status ldns_resolver_send_pkt(ldns_pkt **answer, ldns_resolver *r, ldns_pkt
 
 /**
  * Send a query to a nameserver
+ * \param[out] pkt a packet with the reply from the nameserver
  * \param[in] *r operate using this resolver
  * \param[in] *name query for this name
  * \param[in] *t query for this type (may be 0, defaults to A)
  * \param[in] *c query for this class (may be 0, default to IN)
  * \param[in] flags the query flags
+ *
+ * \return ldns_status LDNS_STATUS_OK on success
+ * if _defnames is true the default domain will be added
+ */
+ldns_status ldns_resolver_query_status(ldns_pkt** pkt, ldns_resolver *r, const ldns_rdf *name, ldns_rr_type t, ldns_rr_class c, uint16_t flags);
+
+
+/**
+ * Send a query to a nameserver
+ * \param[in] *r operate using this resolver 
+ *               (despite the const in the declaration,
+ *                the struct is altered as a side-effect)
+ * \param[in] *name query for this name
+ * \param[in] *t query for this type (may be 0, defaults to A)
+ * \param[in] *c query for this class (may be 0, default to IN)
+ * \param[in] flags the query flags
+ *
  * \return ldns_pkt* a packet with the reply from the nameserver
  * if _defnames is true the default domain will be added
  */
@@ -629,10 +689,17 @@ ldns_pkt* ldns_resolver_query(const ldns_resolver *r, const ldns_rdf *name, ldns
 
 /**
  * Create a new resolver structure
- * \return ldns_resolver* pointer to new strcture
+ * \return ldns_resolver* pointer to new structure
  */
 ldns_resolver* ldns_resolver_new(void);
 
+/**
+ * Clone a resolver
+ * \param[in] r the resolver to clone
+ * \return ldns_resolver* pointer to new structure
+ */
+ldns_resolver* ldns_resolver_clone(ldns_resolver *r);
+
 /**
  * Create a resolver structure from a file like /etc/resolv.conf
  * \param[out] r the new resolver
@@ -655,7 +722,7 @@ ldns_status ldns_resolver_new_frm_fp_l(ldns_resolver **r, FILE *fp, int *line_nr
 /**
  * Configure a resolver by means of a resolv.conf file
  * The file may be NULL in which case there will  be
- * looked the RESOLV_CONF (defaults to /etc/resolv.conf
+ * looked the RESOLV_CONF (defaults to /etc/resolv.conf)
  * \param[out] r the new resolver
  * \param[in] filename the filename to use
  * \return LDNS_STATUS_OK or the error
@@ -663,7 +730,7 @@ ldns_status ldns_resolver_new_frm_fp_l(ldns_resolver **r, FILE *fp, int *line_nr
 ldns_status ldns_resolver_new_frm_file(ldns_resolver **r, const char *filename);
 
 /**
- * Frees the allocated space for this resolver. Only frees the resolver pionter! You should probably be using _deep_free.
+ * Frees the allocated space for this resolver. Only frees the resolver pointer! You should probably be using _deep_free.
  * \param res resolver to free
  */
 void ldns_resolver_free(ldns_resolver *res);
@@ -684,6 +751,12 @@ void ldns_resolver_deep_free(ldns_resolver *res);
  */
 ldns_rr* ldns_axfr_next(ldns_resolver *resolver);
 
+/**
+ * Abort a transfer that is in progress
+ * \param[in] resolver the resolver that is used
+ */
+void ldns_axfr_abort(ldns_resolver *resolver);
+
 /**
  * Returns true if the axfr transfer has completed (i.e. 2 SOA RRs and no errors were encountered
  * \param[in] resolver the resolver that is used
@@ -693,12 +766,26 @@ bool ldns_axfr_complete(const ldns_resolver *resolver);
 
 /**
  * Returns a pointer to the last ldns_pkt that was sent by the server in the AXFR transfer
- * uasable for instance to get the error code on failure
+ * usable for instance to get the error code on failure
  * \param[in] res the resolver that was used in the axfr transfer
  * \return ldns_pkt the last packet sent
  */
 ldns_pkt *ldns_axfr_last_pkt(const ldns_resolver *res);
 
+/**
+ * Get the serial for requesting IXFR.
+ * \param[in] r the resolver
+ * \param[in] serial serial
+ */
+void ldns_resolver_set_ixfr_serial(ldns_resolver *r, uint32_t serial);
+
+/**
+ * Get the serial for requesting IXFR.
+ * \param[in] res the resolver
+ * \return uint32_t serial
+ */
+uint32_t ldns_resolver_get_ixfr_serial(const ldns_resolver *res);
+
 /**
  * Randomize the nameserver list in the resolver
  * \param[in] r the resolver
